@@ -12,8 +12,12 @@ import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_cloudwatch_actions._jsii
+import aws_cdk.aws_events._jsii
+import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_route53._jsii
+import aws_cdk.aws_route53_targets._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.aws_sns._jsii
@@ -23,7 +27,7 @@ import cdk_watchful._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "construct-hub", "0.1.5", __name__[0:-6], "construct-hub@0.1.5.jsii.tgz"
+    "construct-hub", "0.1.19", __name__[0:-6], "construct-hub@0.1.19.jsii.tgz"
 )
 
 __all__ = [
